# About
This is a library used and developed by [egyanamtech](https://egyanamtech.com), to scaffold the Django, VueJS projects using docker-compose in a programatic way.

We use the python cli library, [click](https://click.palletsprojects.com/en/7.x/), which provide the commands/frotnend for this library.
